Parse a GitHub ref string into org, repo, and optional ref
Source:R/utils-github.R
parse_github_ref.RdParse a GitHub ref string into org, repo, and optional ref
R/utils-github.R
parse_github_ref.RdParse a GitHub ref string into org, repo, and optional ref